You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by mm...@apache.org on 2004/11/16 08:44:17 UTC

svn commit: rev 75996 - in incubator/beehive/trunk/wsm: drt/tests/org/apache/beehive/wsm/axis drt/tests/org/apache/beehive/wsm/jsr181/model drt/tests/org/apache/beehive/wsm/jsr181/processor/reflection src/runtime/org/apache/beehive/wsm/axis src/runtime/org/apache/beehive/wsm/jsr181/model src/runtime/org/apache/beehive/wsm/jsr181/processor/apt src/runtime/org/apache/beehive/wsm/jsr181/processor/reflection src/runtime/org/apache/beehive/wsm/jsr181/wsdl

Author: mmerz
Date: Mon Nov 15 23:43:25 2004
New Revision: 75996

Added:
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181MethodMetadataImpl.java
      - copied, changed from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceMETHODMetadata.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181ParameterMetadataImpl.java
      - copied, changed from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServicePARAMETERMetadata.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181TypeMetadataImpl.java
      - copied, changed from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceTYPEMetadata.java
Removed:
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceMETHODMetadata.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServicePARAMETERMetadata.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceTYPEMetadata.java
Modified:
   incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/axis/AxisHookTest.java
   incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/model/Jsr181ModelTest.java
   incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/processor/reflection/WsmAnnotationProcessorTest.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/AnnotatedWebServiceDeploymentHandler.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DeploymentDumper.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DropInDeploymentHandler.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/HandlerHandler.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/apt/WsmAnnotationProcessor.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/reflection/WsmReflectionAnnotationProcessor.java
   incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/wsdl/WSDLProcessor.java
Log:
Renamed classes to support the interfaces for the object model.

Contributor: Daryoush Mehrtash


Modified: incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/axis/AxisHookTest.java
==============================================================================
--- incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/axis/AxisHookTest.java	(original)
+++ incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/axis/AxisHookTest.java	Mon Nov 15 23:43:25 2004
@@ -29,10 +29,13 @@
 import org.apache.axis.description.OperationDesc;
 import org.apache.axis.description.ParameterDesc;
 import org.apache.axis.description.ServiceDesc;
+import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadataImpl;
+import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadataImpl;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.SOAPBindingInfo;
-import org.apache.beehive.wsm.jsr181.model.WebServiceMETHODMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServicePARAMETERMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
 
 /**
  * ****************************************************************************
@@ -57,7 +60,7 @@
     ServiceDesc sd;
 
     public void setUp() throws Exception {
-        WebServiceTYPEMetadata wsm = makeFakeMetadata();
+        Jsr181TypeMetadata wsm = makeFakeMetadata();
         sd = AxisHook.createServiceDesc(wsm, null);
     }
 
@@ -122,9 +125,9 @@
         }
     }
 
-    protected WebServiceTYPEMetadata makeFakeMetadata() {
-        WebServiceTYPEMetadata wstm =
-                new WebServiceTYPEMetadata(WS_CLASS.getName());
+    protected Jsr181TypeMetadata makeFakeMetadata() {
+        Jsr181TypeMetadata wstm =
+                new Jsr181TypeMetadataImpl(WS_CLASS.getName());
         wstm.setWsName(WS_NAME);
         /*
          * NOTE jcolwell@bea.com 2004-Sep-13 -- 
@@ -138,13 +141,13 @@
         return wstm;
     }
 
-    protected WebServiceMETHODMetadata makeFakeOnewayMethod() {
-        WebServiceMETHODMetadata wsmm =
-                new WebServiceMETHODMetadata(WM_JAVAONEWAYMETHODNAME, Void.TYPE);
+    protected Jsr181MethodMetadata makeFakeOnewayMethod() {
+        Jsr181MethodMetadata wsmm =
+                new Jsr181MethodMetadataImpl(WM_JAVAONEWAYMETHODNAME, Void.TYPE);
         wsmm.setWmOperationName(WM_ONEWAY + WM_OPERATION);
         wsmm.setWmAction(WM_ONEWAY + WM_ACTION);
         wsmm.setOneWay(true);
-        WebServicePARAMETERMetadata wspm = new WebServicePARAMETERMetadata();
+        Jsr181ParameterMetadata wspm = new Jsr181ParameterMetadataImpl();
         wspm.setJavaType(String.class);
         wspm.setWpName(WM_ONEWAYPARAM);
         wspm.setWpMode(WebParam.Mode.IN);
@@ -152,14 +155,14 @@
         return wsmm;
     }
 
-    protected WebServiceMETHODMetadata makeFakeMethod() {
-        WebServiceMETHODMetadata wsmm =
-                new WebServiceMETHODMetadata(WM_JAVAMETHODNAME, String.class);
+    protected Jsr181MethodMetadata makeFakeMethod() {
+        Jsr181MethodMetadata wsmm =
+                new Jsr181MethodMetadataImpl(WM_JAVAMETHODNAME, String.class);
         wsmm.setWmOperationName(WM_OPERATION);
         wsmm.setWmAction(WM_ACTION);
         wsmm.setWrName(WM_RESULT);
         wsmm.setOneWay(false);
-        WebServicePARAMETERMetadata wspm = new WebServicePARAMETERMetadata();
+        Jsr181ParameterMetadata wspm = new Jsr181ParameterMetadataImpl();
         wspm.setJavaType(Integer.TYPE);
         wspm.setWpName(WM_TWOWAYPARAM);
         wspm.setWpMode(WebParam.Mode.INOUT);

Modified: incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/model/Jsr181ModelTest.java
==============================================================================
--- incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/model/Jsr181ModelTest.java	(original)
+++ incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/model/Jsr181ModelTest.java	Mon Nov 15 23:43:25 2004
@@ -78,13 +78,13 @@
         String fqClassname = "a.b.c.testclass";
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         typeAnnotations.add(fakeSOAPBindingAnnotation);
-        Collection<WebServiceMETHODMetadata> webMethods =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> webMethods =
+                new ArrayList<Jsr181MethodMetadata>();
 
         // does missing @WebService throw an error?
         try {
-            WebServiceTYPEMetadata type =
-                    new WebServiceTYPEMetadata(null, fqClassname, typeAnnotations, webMethods);
+            Jsr181TypeMetadata type =
+                    new Jsr181TypeMetadataImpl(null, fqClassname, typeAnnotations, webMethods);
             fail("Failed to generate error for TYPE without @WebService annotation");
         } catch (IllegalArgumentException e) {
             // good case
@@ -92,8 +92,8 @@
 
         // does missing fqClassname throw an error?
         try {
-            WebServiceTYPEMetadata type =
-                    new WebServiceTYPEMetadata(fakeWebServiceAnnotation, null, typeAnnotations, webMethods);
+            Jsr181TypeMetadata type =
+                    new Jsr181TypeMetadataImpl(fakeWebServiceAnnotation, null, typeAnnotations, webMethods);
             fail("Failed to generate error for TYPE without TYPE name");
         } catch (IllegalArgumentException e) {
             // good case
@@ -101,8 +101,8 @@
 
         // does missing annotations throw an error?
         try {
-            WebServiceTYPEMetadata type =
-                    new WebServiceTYPEMetadata(fakeWebServiceAnnotation, fqClassname, null, webMethods);
+            Jsr181TypeMetadata type =
+                   new Jsr181TypeMetadataImpl(fakeWebServiceAnnotation, fqClassname, null, webMethods);
             fail("Failed to generate error for TYPE without TYPE annotations");
         } catch (IllegalArgumentException e) {
             // good case
@@ -123,8 +123,8 @@
         /*
          * @WebMethod not required anymore -> endpointInterface/implementation bean
         try {
-            WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, null, null);
+            Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, null, null);
             fail("Error, the METHOD annotation should fail without @WebMethod");
         }
         catch (IllegalArgumentException e)
@@ -133,8 +133,8 @@
         }
         
         try {
-            WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+            Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
             fail("Error, the METHOD annotation should fail without @WebMethod");
         }
         catch (IllegalArgumentException e)
@@ -145,15 +145,15 @@
 
         methodAnnotations.add(new FakeWebMethodAnnotation("", ""));
         try {
-            WebServiceMETHODMetadata method =
-                    new WebServiceMETHODMetadata(null, void.class, false, methodAnnotations, null);
+            Jsr181MethodMetadata method =
+                    new Jsr181MethodMetadataImpl(null, void.class, false, methodAnnotations, null);
             fail("Error, the METHOD annotation should fail without method name");
         } catch (IllegalArgumentException e) {
             // good case
         }
         try {
-            WebServiceMETHODMetadata method =
-                    new WebServiceMETHODMetadata("methodName", null, false, methodAnnotations, null);
+            Jsr181MethodMetadata method =
+                    new Jsr181MethodMetadataImpl("methodName", null, false, methodAnnotations, null);
             fail("Error, the METHOD annotation should fail without return type class");
         } catch (IllegalArgumentException e) {
             // good case
@@ -170,8 +170,8 @@
     //
     public void testPARAMETERConstructor() throws Exception {
         try {
-            WebServicePARAMETERMetadata param =
-                    new WebServicePARAMETERMetadata(null, "paramname", null);
+            Jsr181ParameterMetadata param =
+                    new Jsr181ParameterMetadataImpl(null, "paramname", null);
             fail("Java type is required in for constructor");
         } catch (IllegalArgumentException e) {
             // good case
@@ -185,14 +185,14 @@
     /////////////////////////
     
     public void testTYPEWebServiceDefaults() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation =
                 new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new  Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals("testclass", type.getWsName());
         assertEquals("http://c.b.a", type.getWsTargetNamespace());
         assertEquals("testclassService", type.getWsServiceName());
@@ -201,14 +201,14 @@
     }
 
     public void testTYPEWebService() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation =
                 new FakeWebServiceAnnotation("testname", "testserviceName", "testwsdllocation", "testtargetnamespace", "");
         typeAnnotations.add(wsAnnotation);
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals("testname", type.getWsName());
         assertEquals("testtargetnamespace", type.getWsTargetNamespace());
         assertEquals("testserviceName", type.getWsServiceName());
@@ -225,8 +225,8 @@
     public void testMETHODWebMethodDefaults() throws Exception {
         Collection<Annotation> methodAnnotations = new ArrayList<Annotation>();
         methodAnnotations.add(new FakeWebMethodAnnotation("", ""));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertEquals("methodname", method.getWmOperationName());
         assertEquals("", method.getWmAction());
     }
@@ -236,8 +236,8 @@
         WebMethod mAnnotation =
                 new FakeWebMethodAnnotation("operationname", "action");
         methodAnnotations.add(mAnnotation);
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertEquals("operationname", method.getWmOperationName());
         assertEquals("action", method.getWmAction());
     }
@@ -251,8 +251,8 @@
     public void testMETHODOneWayDefaults() throws Exception {
         Collection<Annotation> methodAnnotations = new ArrayList<Annotation>();
         methodAnnotations.add(new FakeWebMethodAnnotation("", ""));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertFalse(method.isOneWay());
     }
 
@@ -260,8 +260,8 @@
         Collection<Annotation> methodAnnotations = new ArrayList<Annotation>();
         methodAnnotations.add(new FakeWebMethodAnnotation("", ""));
         methodAnnotations.add(new FakeOneWayAnnotation());
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertTrue(method.isOneWay());
     }
     
@@ -275,25 +275,25 @@
         Collection<Annotation> paramAnnotations = new ArrayList<Annotation>();
         WebParam wpAnnotation = new FakeWebParamAnnotation("", "", WebParam.Mode.IN, false);
         paramAnnotations.add(wpAnnotation);
-        WebServicePARAMETERMetadata param =
-                new WebServicePARAMETERMetadata(String.class, "paramname", paramAnnotations);
+        Jsr181ParameterMetadata param =
+                new Jsr181ParameterMetadataImpl(String.class, "paramname", paramAnnotations);
         
         /*** *** ***/
 
         // create param list
-        List<WebServicePARAMETERMetadata> params =
-                new ArrayList<WebServicePARAMETERMetadata>();
+        List<Jsr181ParameterMetadata> params =
+                new ArrayList<Jsr181ParameterMetadata>();
 
         // create methods
-        Collection<WebServiceMETHODMetadata> methods =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methods =
+                new ArrayList<Jsr181MethodMetadata>();
         params.add(param);
         Collection<Annotation> methodAnnotations = new ArrayList<Annotation>();
         WebMethod methodAnnotation =
                 new FakeWebMethodAnnotation("operationname", "action");
         methodAnnotations.add(methodAnnotation);
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, params);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, params);
         methods.add(method);
         
         // create annotations
@@ -302,8 +302,8 @@
         typeAnnotations.add(wsAnnotation);
 
         // create type
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methods);
+        Jsr181TypeMetadata type =
+                new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methods);
 
         /*** *** ***/
         
@@ -318,8 +318,8 @@
         WebParam wpAnnotation =
                 new FakeWebParamAnnotation("paramname", "targetNamespace", WebParam.Mode.INOUT, true);
         paramAnnotations.add(wpAnnotation);
-        WebServicePARAMETERMetadata param =
-                new WebServicePARAMETERMetadata(String.class, "paramname", paramAnnotations);
+        Jsr181ParameterMetadata param =
+                new Jsr181ParameterMetadataImpl(String.class, "paramname", paramAnnotations);
         assertEquals("paramname", param.getWpName());
         assertEquals("targetNamespace", param.getWpTargetNamespace());
         assertEquals(WebParam.Mode.INOUT, param.getWpMode());
@@ -338,14 +338,14 @@
                 new FakeWebMethodAnnotation("operationname", "action");
         methodAnnotations.add(mAnnotation);
         methodAnnotations.add(new FakeWebResultAnnotation("result", ""));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         
         /*** *** ***/
 
         // create methods
-        Collection<WebServiceMETHODMetadata> methods =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methods =
+                new ArrayList<Jsr181MethodMetadata>();
         methods.add(method);
         
         // create annotations
@@ -354,8 +354,8 @@
         typeAnnotations.add(wsAnnotation);
 
         // create type
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methods);
+        Jsr181TypeMetadata type =
+               new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methods);
 
         /*** *** ***/
 
@@ -369,8 +369,8 @@
                 new FakeWebMethodAnnotation("operationname", "action");
         methodAnnotations.add(mAnnotation);
         methodAnnotations.add(new FakeWebResultAnnotation("result", "targetNamespace"));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertEquals("result", method.getWrName());
         assertEquals("targetNamespace", method.getWrTargetNamespace());
     }
@@ -386,14 +386,14 @@
     public void testTYPEHandlerChain() throws Exception {
         String hcFileName = "org/apache/beehive/wsm/jsr181/model/fakeAnnotations/handlerChainConfig.xml";
         String hcName = "testname";
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         typeAnnotations.add(new FakeHandlerChainAnnotation(hcFileName, hcName));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new  Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals(hcFileName, type.getHcFileName());
         assertEquals(hcName, type.getHcName());
     }
@@ -407,8 +407,8 @@
     // no default values to check
 
     public void testTYPESOAPBinding() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation =
                 new FakeWebServiceAnnotation("", "", "", "", "");
@@ -416,8 +416,8 @@
         typeAnnotations.add(new FakeSOAPBindingAnnotation(SOAPBinding.Style.RPC,
                 SOAPBinding.Use.ENCODED,
                 SOAPBinding.ParameterStyle.BARE));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals(SOAPBinding.Style.RPC, type.getSoapBinding().getStyle());
         assertEquals(SOAPBinding.Use.ENCODED, type.getSoapBinding().getUse());
         assertEquals(SOAPBinding.ParameterStyle.BARE, type.getSoapBinding().getParameterStyle());
@@ -431,23 +431,23 @@
 
     // test empty handler list
     public void testTYPESoapMessageHandlersDefaults1() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         FakeSOAPMessageHandlerAnnotation[] emptyHandlers =
                 new FakeSOAPMessageHandlerAnnotation[0];
         typeAnnotations.add(new FakeSOAPMessageHandlersAnnotation(emptyHandlers));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+              new  Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertTrue(type.getSoapHandlers().isEmpty());
     }
 
     // test single default handler in handlers list
     public void testTYPESoapMessageHandlersDefaults2() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
@@ -455,8 +455,8 @@
             new FakeSOAPMessageHandlerAnnotation("", "soaphandlerclass", new FakeInitParamAnnotation[0], new String[0], new String[0])
         };
         typeAnnotations.add(new FakeSOAPMessageHandlersAnnotation(defaultHandlers));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals("number of handlers returned: " + type.getSoapHandlers().size(),
                 1, type.getSoapHandlers().size());
         SOAPMessageHandlerInfo handler = type.getSoapHandlers().get(0);
@@ -468,8 +468,8 @@
     }
 
     public void testTYPESoapMessageHandlers() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
@@ -482,8 +482,8 @@
             new FakeSOAPMessageHandlerAnnotation("", "soaphandlerclass", params, roles, headers)
         };
         typeAnnotations.add(new FakeSOAPMessageHandlersAnnotation(defaultHandlers));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+              new  Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         
         // handlers
         List<SOAPMessageHandlerInfo> soapHandlers = type.getSoapHandlers();
@@ -517,29 +517,29 @@
     /////////////////////////
 
     public void testTYPESecurityRolesDefaults() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         typeAnnotations.add(new FakeSecurityRoleAnnotation(null, null));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+              new  Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertNull(type.getSecurityRoles().getRolesAllowed());
         assertNull(type.getSecurityRoles().getRolesReferenced());
     }
 
     public void testTYPESecurityRoles() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         String[] rolesAllowed = {"rolesallowed"};
         String[] rolesReferenced = {"rolesreferenced"};
         typeAnnotations.add(new FakeSecurityRoleAnnotation(rolesAllowed, rolesReferenced));
-        WebServiceTYPEMetadata type =
-                new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type =
+               new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals(1, type.getSecurityRoles().getRolesAllowed().size());
         assertEquals("rolesallowed", (String) type.getSecurityRoles().getRolesAllowed().iterator().next());
         assertEquals(1, type.getSecurityRoles().getRolesReferenced().size());
@@ -553,24 +553,24 @@
     /////////////////////////
 
     public void testTYPESecurityIdentityDefaults() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         typeAnnotations.add(new FakeSecurityIdentityAnnotation(null));
-        WebServiceTYPEMetadata type = new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type = new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertNull(type.getSiValue());
     }
 
     public void testTYPESecurityIdentity() throws Exception {
-        Collection<WebServiceMETHODMetadata> methodMetadata =
-                new ArrayList<WebServiceMETHODMetadata>();
+        Collection<Jsr181MethodMetadata> methodMetadata =
+                new ArrayList<Jsr181MethodMetadata>();
         Collection<Annotation> typeAnnotations = new ArrayList<Annotation>();
         WebService wsAnnotation = new FakeWebServiceAnnotation("", "", "", "", "");
         typeAnnotations.add(wsAnnotation);
         typeAnnotations.add(new FakeSecurityIdentityAnnotation("value"));
-        WebServiceTYPEMetadata type = new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
+        Jsr181TypeMetadata type = new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, methodMetadata);
         assertEquals(type.getSiValue(), "value");
     }
 
@@ -590,12 +590,12 @@
                             "serviceName",
                             "wsdlLocation",
                             "targetNamespace",
-                            "endpointInterface");
+                            "esndpointInterface");
             typeAnnotations.add(wsAnnotation);
             typeAnnotations.add(new FakeSOAPMessageHandlersAnnotation(new SOAPMessageHandler[0]));
             typeAnnotations.add(new FakeHandlerChainAnnotation("fileName", "chainName"));
-            WebServiceTYPEMetadata type =
-                    new WebServiceTYPEMetadata(wsAnnotation, "a.b.c.testclass", typeAnnotations, new ArrayList<WebServiceMETHODMetadata>());
+            Jsr181TypeMetadata type =
+                    new Jsr181TypeMetadataImpl(wsAnnotation, "a.b.c.testclass", typeAnnotations, new ArrayList<Jsr181MethodMetadata>());
         } catch (Exception e) {
             hasPassed = true;
         }
@@ -610,8 +610,8 @@
                 new FakeWebMethodAnnotation("operationname", "action");
         methodAnnotations.add(mAnnotation);
         methodAnnotations.add(new FakeSecurityRoleAnnotation(null, null));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertNull(method.getSecurityRoles().getRolesAllowed());
         assertNull(method.getSecurityRoles().getRolesReferenced());
     }
@@ -625,8 +625,8 @@
         String[] rolesReferenced = {"rolesreferenced"};
         methodAnnotations.add(new FakeSecurityRoleAnnotation(rolesAllowed,
                 rolesReferenced));
-        WebServiceMETHODMetadata method =
-                new WebServiceMETHODMetadata("methodname", void.class, false, methodAnnotations, null);
+        Jsr181MethodMetadata method =
+                new Jsr181MethodMetadataImpl("methodname", void.class, false, methodAnnotations, null);
         assertEquals(1, method.getSecurityRoles().getRolesAllowed().size());
         assertEquals("rolesallowed", method.getSecurityRoles().getRolesAllowed().iterator().next());
         assertEquals(1, method.getSecurityRoles().getRolesReferenced().size());
@@ -642,7 +642,7 @@
             methodAnnotations.add(mAnnotation);
             methodAnnotations.add(new FakeOneWayAnnotation());
             methodAnnotations.add(new FakeWebResultAnnotation("result", ""));
-            WebServiceMETHODMetadata method = new WebServiceMETHODMetadata("methodname",
+            Jsr181MethodMetadata method = new Jsr181MethodMetadataImpl("methodname",
                     void.class,
                     false,
                     methodAnnotations,
@@ -663,7 +663,7 @@
                     new FakeWebMethodAnnotation("operationname", "action");
             methodAnnotations.add(mAnnotation);
             methodAnnotations.add(new FakeOneWayAnnotation());
-            WebServiceMETHODMetadata method = new WebServiceMETHODMetadata("methodname",
+            Jsr181MethodMetadata method = new Jsr181MethodMetadataImpl("methodname",
                     int.class,
                     false,
                     methodAnnotations,
@@ -685,7 +685,7 @@
                     new FakeWebMethodAnnotation("operationname", "action");
             methodAnnotations.add(mAnnotation);
             methodAnnotations.add(new FakeOneWayAnnotation());
-            WebServiceMETHODMetadata method = new WebServiceMETHODMetadata("methodname",
+            Jsr181MethodMetadata method = new Jsr181MethodMetadataImpl("methodname",
                     void.class,
                     true,
                     methodAnnotations,
@@ -707,20 +707,20 @@
                     new FakeWebMethodAnnotation("operationname", "action");
             methodAnnotations.add(mAnnotation);
             methodAnnotations.add(new FakeOneWayAnnotation());
-            List<WebServicePARAMETERMetadata> params =
-                    new ArrayList<WebServicePARAMETERMetadata>();
+            List<Jsr181ParameterMetadata> params =
+                    new ArrayList<Jsr181ParameterMetadata>();
             Collection<Annotation> paramAnnotations =
                     new ArrayList<Annotation>();
             FakeWebParamAnnotation pAnnotation =
                     new FakeWebParamAnnotation("param", "", WebParam.Mode.OUT, false);
             paramAnnotations.add(pAnnotation);
-            WebServicePARAMETERMetadata param =
-                    new WebServicePARAMETERMetadata(String.class, // javaType
+            Jsr181ParameterMetadata param =
+                    new Jsr181ParameterMetadataImpl(String.class, // javaType
                             "paramname", // name
                             paramAnnotations // annotations
                     );
             params.add(param);
-            WebServiceMETHODMetadata method = new WebServiceMETHODMetadata("methodname",
+            Jsr181MethodMetadata method = new Jsr181MethodMetadataImpl("methodname",
                     void.class,
                     false,
                     methodAnnotations,

Modified: incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/processor/reflection/WsmAnnotationProcessorTest.java
==============================================================================
--- incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/processor/reflection/WsmAnnotationProcessorTest.java	(original)
+++ incubator/beehive/trunk/wsm/drt/tests/org/apache/beehive/wsm/jsr181/processor/reflection/WsmAnnotationProcessorTest.java	Mon Nov 15 23:43:25 2004
@@ -20,7 +20,6 @@
 
 import org.apache.beehive.wsm.jsr181.model.FooTestCase;
 import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServicePARAMETERMetadata;
 
 /**
  * Test case verifies that a class file can be read and its annotations can be

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/AnnotatedWebServiceDeploymentHandler.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/AnnotatedWebServiceDeploymentHandler.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/AnnotatedWebServiceDeploymentHandler.java	Mon Nov 15 23:43:25 2004
@@ -35,7 +35,7 @@
 import org.apache.axis.handlers.BasicHandler;
 import org.apache.axis.handlers.soap.SOAPService;
 import org.apache.axis.providers.java.RPCProvider;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
 import org.apache.beehive.wsm.jsr181.processor.reflection.WsmReflectionAnnotationProcessor;
 import org.apache.commons.logging.Log;
 
@@ -107,8 +107,8 @@
         if (null != clazz) {
             rpc = soapServices.get(clazz.getName());
             if (null == rpc) {
-                WebServiceTYPEMetadata wsm =
-                        (WebServiceTYPEMetadata) WsmReflectionAnnotationProcessor.getInstance().getObjectModel(clazz);
+                Jsr181TypeMetadata wsm =
+                        (Jsr181TypeMetadata) WsmReflectionAnnotationProcessor.getInstance().getObjectModel(clazz);
                 rpc = createSOAPServiceUsingAnnotations(wsm, clazz);
             }
         }
@@ -121,7 +121,7 @@
      * @return
      * @throws Exception
      */
-    protected SOAPService createSOAPServiceUsingAnnotations(WebServiceTYPEMetadata wsm, Class cls)
+    protected SOAPService createSOAPServiceUsingAnnotations(Jsr181TypeMetadata wsm, Class cls)
             throws Exception {
         SOAPService rpc = null;
         if (null != wsm) {

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DeploymentDumper.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DeploymentDumper.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DeploymentDumper.java	Mon Nov 15 23:43:25 2004
@@ -39,7 +39,7 @@
 import org.apache.axis.description.OperationDesc;
 import org.apache.axis.encoding.SerializationContext;
 import org.apache.axis.server.AxisServer;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
 import org.apache.beehive.wsm.jsr181.processor.apt.WsmAnnotationProcessor;
 
 /**
@@ -76,7 +76,7 @@
         }
     }
 
-    public void createAxisDeployment(Collection<WebServiceTYPEMetadata> wsms,
+    public void createAxisDeployment(Collection<Jsr181TypeMetadata> wsms,
                                      String newConfigFilename,
                                      String existingConfigFilename)
             throws Exception {
@@ -101,7 +101,7 @@
             fp.configureEngine(new AxisServer());
             WSDDDeployment dep = fp.getDeployment();
             if (dep != null) {
-                for (WebServiceTYPEMetadata wsm : wsms) {
+                for (Jsr181TypeMetadata wsm : wsms) {
                     WSDDService wsds = new WSDDService();
                     JavaServiceDesc sd = (JavaServiceDesc)
                             AxisHook.createServiceDesc(wsm, getClass()
@@ -162,12 +162,12 @@
         fw.close();
     }
 
-    protected Collection<WebServiceTYPEMetadata> retrieveWebServiceMetadata() {
-        Collection<WebServiceTYPEMetadata> meta =
-                new ArrayList<WebServiceTYPEMetadata>();
+    protected Collection<Jsr181TypeMetadata> retrieveWebServiceMetadata() {
+        Collection<Jsr181TypeMetadata> meta =
+                new ArrayList<Jsr181TypeMetadata>();
         Set<String> keys = WsmAnnotationProcessor.getObjectModelNames();
         for (String key : keys) {
-            meta.add((WebServiceTYPEMetadata) WsmAnnotationProcessor
+            meta.add((Jsr181TypeMetadata) WsmAnnotationProcessor
                     .getObjectModel(key));
         }
         return meta;

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DropInDeploymentHandler.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DropInDeploymentHandler.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/DropInDeploymentHandler.java	Mon Nov 15 23:43:25 2004
@@ -48,7 +48,7 @@
 import org.apache.axis.utils.Messages;
 import org.apache.axis.utils.XMLUtils;
 import org.apache.axis.utils.ClasspathUtils;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
 import org.apache.beehive.wsm.jsr181.processor.reflection.WsmReflectionAnnotationProcessor;
 import org.apache.commons.logging.Log;
 import org.w3c.dom.Document;
@@ -123,8 +123,8 @@
         if (null != clazz) {
             rpc = soapServices.get(clazz.getName());
             if (null == rpc) {
-                WebServiceTYPEMetadata wsm =
-                        (WebServiceTYPEMetadata) WsmReflectionAnnotationProcessor.getInstance().getObjectModel(clazz);
+                Jsr181TypeMetadata wsm =
+                        (Jsr181TypeMetadata) WsmReflectionAnnotationProcessor.getInstance().getObjectModel(clazz);
                 rpc = createSOAPServiceUsingAnnotations(wsm, clazz);
             }
         }
@@ -137,7 +137,7 @@
      * @return
      * @throws Exception
      */
-    protected SOAPService createSOAPServiceUsingAnnotations(WebServiceTYPEMetadata wsm, Class cls)
+    protected SOAPService createSOAPServiceUsingAnnotations(Jsr181TypeMetadata wsm, Class cls)
             throws Exception {
         SOAPService rpc = null;
         if (null != wsm) {

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/HandlerHandler.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/HandlerHandler.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/axis/HandlerHandler.java	Mon Nov 15 23:43:25 2004
@@ -20,8 +20,8 @@
 package org.apache.beehive.wsm.axis;
 
 import org.apache.axis.handlers.JAXRPCHandler;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
 import org.apache.beehive.wsm.jsr181.model.SOAPMessageHandlerInfo;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
 
 /**
  * ****************************************************************************
@@ -34,14 +34,14 @@
  */
 public class HandlerHandler extends JAXRPCHandler {
 
-    private WebServiceTYPEMetadata wsm;
+    private Jsr181TypeMetadata wsm;
 
     /**
-     * Constructor with WebServiceTYPEMetadata parameter
+     * Constructor with Jsr181TypeMetadata parameter
      *
      * @param wsm
      */
-    public HandlerHandler(WebServiceTYPEMetadata wsm) {
+    public HandlerHandler(Jsr181TypeMetadata wsm) {
         this.wsm = wsm;
     }
 

Copied: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181MethodMetadataImpl.java (from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceMETHODMetadata.java)
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceMETHODMetadata.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181MethodMetadataImpl.java	Mon Nov 15 23:43:25 2004
@@ -30,7 +30,7 @@
 import javax.jws.WebResult;
 import javax.jws.security.SecurityRoles;
 
-public class WebServiceMETHODMetadata implements Jsr181MethodMetadata {
+public class Jsr181MethodMetadataImpl implements Jsr181MethodMetadata {
     private String wmOperationName;
     private String wmAction;
     private boolean oneway = false;
@@ -46,13 +46,13 @@
         return; // no validation required
     }
 
-    public WebServiceMETHODMetadata(String methodName, Class returnType) {
+    public Jsr181MethodMetadataImpl(String methodName, Class returnType) {
         super();
         javaMethodName = methodName;
         javaReturnType = returnType;
     }
 
-    public WebServiceMETHODMetadata(String javaMethodName,
+    public Jsr181MethodMetadataImpl(String javaMethodName,
                                     Class javaReturnType,
                                     boolean throwsExceptions,
                                     Collection<Annotation> annotations,

Copied: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181ParameterMetadataImpl.java (from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServicePARAMETERMetadata.java)
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServicePARAMETERMetadata.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181ParameterMetadataImpl.java	Mon Nov 15 23:43:25 2004
@@ -23,7 +23,7 @@
 
 import javax.jws.WebParam;
 
-public class WebServicePARAMETERMetadata  implements Jsr181ParameterMetadata {
+public class Jsr181ParameterMetadataImpl  implements Jsr181ParameterMetadata {
     private String wpName;
     private String wpTargetNamespace;
     private WebParam.Mode wpMode;
@@ -34,13 +34,13 @@
         return; // no validation required
     }
 
-    public WebServicePARAMETERMetadata() {
+    public Jsr181ParameterMetadataImpl() {
         super();
     }
 
     // defaultName is argument name in the source file. It can be null if the
     // name is not known.
-    public WebServicePARAMETERMetadata(Class javaType,
+    public Jsr181ParameterMetadataImpl(Class javaType,
                                        String defaultName,
                                        Collection<Annotation> annotations) {
         // check parameters

Copied: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181TypeMetadataImpl.java (from rev 71514, incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceTYPEMetadata.java)
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/apt/WsmAnnotationProcessor.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/apt/WsmAnnotationProcessor.java	Mon Nov 15 23:43:25 2004
@@ -41,10 +41,11 @@
 import org.apache.beehive.wsm.jsr181.model.AnnotationMetadata;
 import org.apache.beehive.wsm.jsr181.model.AnnotationModel;
 import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceMETHODMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServicePARAMETERMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadataImpl;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadataImpl;
 import org.apache.beehive.wsm.jsr181.processor.ProcessorException;
 
 /**
@@ -145,10 +146,10 @@
         }
 
         // create & return webService
-        WebServiceTYPEMetadata wstm = null;
+        Jsr181TypeMetadata wstm = null;
         try {
             Collection<Annotation> annotations = getAnnotations(decl);
-            wstm = new WebServiceTYPEMetadata((javax.jws.WebService)
+            wstm = new Jsr181TypeMetadataImpl((javax.jws.WebService)
                     AnnotationModel.getAnnotationOfType(annotations,
                             javax.jws.WebService.class),
                     decl.getQualifiedName(),
@@ -169,10 +170,10 @@
         }
 
         // create & return webMethod
-        WebServiceMETHODMetadata wsmm = null;
+        Jsr181MethodMetadata wsmm = null;
         try {
             Collection<Annotation> annotations = getAnnotations(decl);
-            wsmm = new WebServiceMETHODMetadata(decl.getSimpleName(),
+            wsmm = new Jsr181MethodMetadataImpl(decl.getSimpleName(),
                     TypeMirrorUtil.classForName(decl.getReturnType()),
                     (0 < decl.getThrownTypes().size()),
                     annotations,
@@ -185,10 +186,10 @@
 
     protected Jsr181ParameterMetadata getWebServicePARAMETERMetadata(ParameterDeclaration decl) {
         // create & return webParam
-        WebServicePARAMETERMetadata wspm = null;
+        Jsr181ParameterMetadata wspm = null;
         try {
             Collection<Annotation> annotations = getAnnotations(decl);
-            wspm = new WebServicePARAMETERMetadata(TypeMirrorUtil.classForName(decl.getType()),
+            wspm = new Jsr181ParameterMetadataImpl(TypeMirrorUtil.classForName(decl.getType()),
                     decl.getSimpleName(),
                     annotations);
         } catch (Throwable t) {

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/reflection/WsmReflectionAnnotationProcessor.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/reflection/WsmReflectionAnnotationProcessor.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/reflection/WsmReflectionAnnotationProcessor.java	Mon Nov 15 23:43:25 2004
@@ -31,11 +31,12 @@
 import org.apache.beehive.wsm.jsr181.model.AnnotationMetadata;
 import org.apache.beehive.wsm.jsr181.model.AnnotationModel;
 import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceMETHODMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServicePARAMETERMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadataImpl;
+
 
 public class WsmReflectionAnnotationProcessor {
     private static WsmReflectionAnnotationProcessor _instance;
@@ -109,7 +110,7 @@
         // create & return WebService
         Jsr181TypeMetadata wstm = null;
         try {
-            wstm = new WebServiceTYPEMetadata((WebService) sibClass.getAnnotation(WebService.class),
+            wstm = new Jsr181TypeMetadataImpl((WebService) sibClass.getAnnotation(WebService.class),
                     sibClass.getName(),
                     annotations,
                     webMethods);
@@ -142,7 +143,7 @@
         // create & return webMethod
         Jsr181MethodMetadata wsmm = null;
         try {
-            wsmm = new WebServiceMETHODMetadata(method.getName(),
+            wsmm = new Jsr181MethodMetadataImpl(method.getName(),
                     method.getReturnType(),
                     (0 < method.getExceptionTypes().length),
                     Arrays.asList(method.getAnnotations()),
@@ -164,7 +165,7 @@
         // create & return webParam
         Jsr181ParameterMetadata wspm = null;
         try {
-            wspm = new WebServicePARAMETERMetadata(paramType,
+            wspm = new Jsr181ParameterMetadataImpl(paramType,
                     "in" + offset, // by default parameter should be IN
                     annotations);
         } catch (Throwable t) {

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/wsdl/WSDLProcessor.java
==============================================================================
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/wsdl/WSDLProcessor.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/wsdl/WSDLProcessor.java	Mon Nov 15 23:43:25 2004
@@ -34,12 +34,12 @@
 import javax.xml.namespace.QName;
 
 import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181MethodMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181ParameterMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadata;
+import org.apache.beehive.wsm.jsr181.model.Jsr181TypeMetadataImpl;
 import org.apache.beehive.wsm.jsr181.model.SOAPBindingInfo;
-import org.apache.beehive.wsm.jsr181.model.WebServiceMETHODMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServicePARAMETERMetadata;
-import org.apache.beehive.wsm.jsr181.model.WebServiceTYPEMetadata;
 
 import org.apache.xmlbeans.SchemaType;
 import org.apache.xmlbeans.XmlCursor;
@@ -79,7 +79,7 @@
     public static Jsr181TypeMetadata toWebServiceMetadata
             (DefinitionsDocument defDoc)
             throws IllegalAccessException, NoSuchFieldException {
-    	Jsr181TypeMetadata wsm = new WebServiceTYPEMetadata(null);
+    	Jsr181TypeMetadata wsm = new Jsr181TypeMetadataImpl(null);
         Map<String, Jsr181MethodMetadata> methodMap =
                 new HashMap<String, Jsr181MethodMetadata>();
         TDefinitions defs = defDoc.getDefinitions();
@@ -167,7 +167,7 @@
             }
         }
         Jsr181MethodMetadata wmm =
-                new WebServiceMETHODMetadata(opName, returnType);
+                new Jsr181MethodMetadataImpl(opName, returnType);
         //wmm.setJavaMethodName(opName);
         wmm.setWmOperationName(opName);
         methodMap.put(opName, wmm);
@@ -186,7 +186,7 @@
                     if (ord.equals(currentParam.getName())) {
                         QName qParamType = currentParam.getType();
                         Jsr181ParameterMetadata wpm =
-                                new WebServicePARAMETERMetadata();
+                                new Jsr181ParameterMetadataImpl();
                         /* wpm.setJavaType(qParamType.getNamespaceURI() +
                            '.' + qParamType.getLocalPart());*/
                         wpm.setWpName((String) ord);
--- incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/WebServiceTYPEMetadata.java	(original)
+++ incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/model/Jsr181TypeMetadataImpl.java	Mon Nov 15 23:43:25 2004
@@ -48,7 +48,7 @@
 import org.w3c.dom.NodeList;
 import org.xmlsoap.schemas.wsdl.DefinitionsDocument;
 
-public class WebServiceTYPEMetadata implements Jsr181TypeMetadata  {
+public class Jsr181TypeMetadataImpl implements Jsr181TypeMetadata  {
     private String wsName;
     private String wsServiceName;
     private String wsWsdlLocation;
@@ -72,7 +72,7 @@
      * @param sibClassName The fully-qualified name of the service
      *                     implementation bean class.
      */
-    public WebServiceTYPEMetadata(String sibClassName) {
+    public Jsr181TypeMetadataImpl(String sibClassName) {
         super();
         this.sibClassName = sibClassName;
     }
@@ -91,7 +91,7 @@
      * @param webMethods      All methods that are published by the service.
      * @throws Exception
      */
-    public WebServiceTYPEMetadata(WebService sibWsAnnotation,
+    public Jsr181TypeMetadataImpl(WebService sibWsAnnotation,
                                   String sibClassName,
                                   Collection<Annotation> annotations,
                                   Collection<? extends Jsr181MethodMetadata> webMethods) throws Exception {
@@ -164,7 +164,7 @@
             }
         }
         
         // set WebServiceMETHODMetadata and back fill JSR-181 default values
         for (Jsr181MethodMetadata wsmm : webMethods) {
             // JSR-181 defaults: fill in default for tergetNamespace from @WebService
             String wrTargetNamespace = wsmm.getWrTargetNamespace();
@@ -483,16 +483,16 @@
      */
     private void validateDuplicatedMethods () throws ValidationException
     {
-        WebServiceMETHODMetadata[] methods = getMethods().toArray(new WebServiceMETHODMetadata[]{});
+        Jsr181MethodMetadata[] methods = getMethods().toArray(new Jsr181MethodMetadata[]{});
         for ( int i = 0 ; i < methods.length ; i++ )
         {
-            WebServiceMETHODMetadata method = methods[i];
+            Jsr181MethodMetadata method = methods[i];
             String methodName = method.getWmOperationName();
             for ( int k = 0 ; k < methods.length ; k++ )
             {
                 if ( i == k ) continue;  // skip the same method.
 
-                WebServiceMETHODMetadata method_ = methods[k];
+                Jsr181MethodMetadata method_ = methods[k];
                 if ( methodName.equals( method_.getWmOperationName() ) )
                 {
                     // Found the duplicated method's name !
@@ -529,11 +529,11 @@
      * @param m2
      * @return boolean
      */
-    private boolean hasSameParameterTypes ( WebServiceMETHODMetadata m1, WebServiceMETHODMetadata m2 )
+    private boolean hasSameParameterTypes ( Jsr181MethodMetadata m1, Jsr181MethodMetadata m2 )
     {
 
-        WebServicePARAMETERMetadata[] params1 = m1.getParams().toArray( new WebServicePARAMETERMetadata[]{} );
-        WebServicePARAMETERMetadata[] params2 = m2.getParams().toArray( new WebServicePARAMETERMetadata[]{} );
+        Jsr181ParameterMetadata[] params1 = m1.getParams().toArray( new Jsr181ParameterMetadata[]{} );
+        Jsr181ParameterMetadata[] params2 = m2.getParams().toArray( new Jsr181ParameterMetadata[]{} );
 
         // check number of parameters.
         if ( params1.length != params2.length )
@@ -164,7 +164,7 @@
         }
         
-        // set WebServiceMETHODMetadata and back fill JSR-181 default values
+        // set Jsr181MethodMetadata and back fill JSR-181 default values
         for (Jsr181MethodMetadata wsmm : webMethods) {
             // JSR-181 defaults: fill in default for tergetNamespace from @WebService

Modified: incubator/beehive/trunk/wsm/src/runtime/org/apache/beehive/wsm/jsr181/processor/apt/WsmAnnotationProcessor.java
==============================================================================